Coverage report

|  | Statements |  | Branches |  | Total
--- | --- | --- | --- | --- | --- | ---
File |  | coverage | statements | missing | excluded |  | coverage | branches | partial |  | coverage
src / nanocli / __init__.py |  | 100% | 4 | 0 | 0 |  | 100% | 0 | 0 |  | 100%
src / nanocli / config.py |  | 92% | 106 | 9 | 0 |  | 80% | 46 | 7 |  | 88%
src / nanocli / core.py |  | 98% | 270 | 6 | 0 |  | 86% | 110 | 15 |  | 94%
Total |  | 96% | 380 | 15 | 0 |  | 85% | 156 | 22 |  | 93%

No items found using the specified filter.